#include "txtfont.h"

unsigned int TXT_Mask[11]= {
   0x0000,  // ************ ****
   0x39C0,  // **###**###** ****
   0x39C0,  // **###**###** ****
   0x0000,  // ************ ****
   0x39C0,  // **###**###** ****
   0x39C0,  // **###**###** ****
   0x0000,  // ************ ****
   0x39C0,  // **###**###** ****
   0x39C0,  // **###**###** ****
   0x0000   // ************ ****
  };

unsigned int TXT_Font[][11]= {
  { // 0x20 = Leerzeichen
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x21 = !
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x22 = "
   0x0000,  // ************ ****
   0x39C0,  // **###**###** ****
   0x18C0,  // ***##***##** ****
   0x3180,  // **##***##*** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x23 = # = NC 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x0000   // ************ ****
  },
  { // 0x24 = $ = NC
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x6660,  // *##**##**##* ****
   0x6600,  // *##**##***** ****
   0x3FC0,  // **########** ****
   0x0660,  // *****##**##* ****
   0x6660,  // *##**##**##* ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
  },
  { // 0x25 = %
   0x0000,  // ************ ****
   0x70C0,  // *###****##** ****
   0xD980,  // ##*##**##*** ****
   0x7300,  // *###**##**** ****
   0x0600,  // *****##***** ****
   0x0CE0,  // ****##**###* ****
   0x19B0,  // ***##**##*## ****
   0x30E0,  // **##****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x26 = & 
   0x0000,  // ************ ****
   0x1E00,  // ***####***** ****
   0x3300,  // **##**##**** ****
   0x3300,  // **##**##**** ****
   0x1E00,  // ***####***** ****
   0x3330,  // **##**##**## ****
   0x61C0,  // *##****###** ****
   0x3F30,  // **######**## ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x27 = '
   0x0000,  // ************ ****
   0x0700,  // *****###**** ****
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x28 = (
   0x0000,  // ************ ****
   0x0700,  // *****###**** ****
   0x0C00,  // ****##****** ****
   0x1800,  // ***##******* ****
   0x1800,  // ***##******* ****
   0x1800,  // ***##******* ****
   0x0C00,  // ****##****** ****
   0x0700,  // *****###**** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x29 = )
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0300,  // ******##**** ****
   0x0180,  // *******##*** ****
   0x0180,  // *******##*** ****
   0x0180,  // *******##*** ****
   0x0300,  // ******##**** ****
   0x0E00,  // ****###***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x2A = *
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x6660,  // *##**##**##* ****
   0x36C0,  // **##*##*##** ****
   0x0F00,  // ****####**** ****
   0x36C0,  // **##*##*##** ****
   0x6660,  // *##**##**##* ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x2B = +
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x2C = ,
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3800,  // **###******* ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
  },
  { // 0x2D = -
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x2E = .
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1800,  // ***##******* ****
   0x1800,  // ***##******* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x2F = /
   0x0000,  // ************ ****
   0x00C0,  // ********##** ****
   0x0180,  // *******##*** ****
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0C00,  // ****##****** ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },

  { // 0x30 = 0
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x31 = 1
   0x0000,  // ************ ****
   0x0700,  // *****###**** ****
   0x1F00,  // ***#####**** ****
   0x0700,  // *****###**** ****
   0x0700,  // *****###**** ****
   0x0700,  // *****###**** ****
   0x0700,  // *****###**** ****
   0x0700,  // *****###**** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x32 = 2
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x30E0,  // **##****###* ****
   0x00E0,  // ********###* ****
   0x01C0,  // *******###** ****
   0x0780,  // *****####*** ****
   0x1E00,  // ***####***** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x33 = 3
   0x0000,  // ************ ****
   0x3FE0,  // **#########* ****
   0x00C0,  // ********##** ****
   0x0080,  // *******##*** ****
   0x07E0,  // *****######* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x34 = 4
   0x0000,  // ************ ****
   0x00E0,  // ********###* ****
   0x03C0,  // ******####** ****
   0x0700,  // *****###**** ****
   0x1C00,  // ***###****** ****
   0x38E0,  // **###***###* ****
   0x3FE0,  // **#########* ****
   0x00E0,  // ********###* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x35 = 5
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3FC0,  // **########** ****
   0x00E0,  // ********###* ****
   0x30E0,  // **##****###* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x36 = 6
   0x0000,  // ************ ****
   0x0700,  // *****###**** ****
   0x0E00,  // ****###***** ****
   0x1C00,  // ***###****** ****
   0x3FC0,  // **########** ****
   0x3860,  // **###****##* ****
   0x3860,  // **###****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x37 = 7
   0x0000,  // ************ ****
   0x7FE0,  // *##########* ****
   0x01C0,  // *******###** ****
   0x0380,  // ******###*** ****
   0x0700,  // *****###**** ****
   0x0E00,  // ****###***** ****
   0x1C00,  // ***###****** ****
   0x3800,  // **###******* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x38 = 8
   0x0000,  // ************ ****
   0x0F80,  // ****#####*** ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x0F80,  // ****#####*** ****
   0x38E0,  // **###***###* ****
   0x38E0,  // **###***###* ****
   0x0F80,  // ****#####*** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x39 = 9
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x30E0,  // **##****###* ****
   0x30E0,  // **##****###* ****
   0x1FC0,  // ***#######** ****
   0x0380,  // ******###*** ****
   0x0700,  // *****###**** ****
   0x0E00,  // ****###***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x3A = :
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0000,  // ************ ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x3B = ;
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x1800,  // ***##******* ****
  },
  { // 0x3C = <
   0x0000,  // ************ ****
   0x00E0,  // ********###* ****
   0x0380,  // ******###*** ****
   0x0E00,  // ****###***** ****
   0x3800,  // **###******* ****
   0x0E00,  // ****###***** ****
   0x0380,  // ******###*** ****
   0x00E0,  // ********###* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x3D = =
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x3E = >
   0x0000,  // ************ ****
   0x7000,  // *###******** ****
   0x1C00,  // ***###****** ****
   0x0700,  // *****###**** ****
   0x01C0,  // *******###** ****
   0x0700,  // *****###**** ****
   0x1C00,  // ***###****** ****
   0x7000,  // *###******** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },
  { // 0x3F = ?
   0x0000,  // ************ ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x0180,  // *******##*** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
  },

  { // 0x40 = § = NC
   0x0000,  // ************ ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x3000,  // **##******** ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x1F80,  // ***######*** ****
   0x00C0,  // ********##** ****
   0x30C0,  // **##****##** ****
   0x1F80   // ***######*** ****
  },
  { // 0x41 = A
   0x0000,  // ************ ****
   0x0F00,  // ****####**** ****
   0x1980,  // ***##**##*** ****
   0x30C0,  // **##****##** ****
   0x6060,  // *##******##* ****
   0x7FE0,  // *##########* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x42 = B
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FC0,  // **########** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x43 = C
   0x0000,  // ************ ****
   0x0FC0,  // ****######** ****
   0x1860,  // ***##****##* ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x1860,  // ***##****##* ****
   0x0FC0,  // ****######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x44 = D
   0x0000,  // ************ ****
   0x3F80,  // **#######*** ****
   0x30C0,  // **##****##** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30C0,  // **##****##** ****
   0x3F80,  // **#######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x45 = E
   0x0000,  // ************ ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3F80,  // **#######*** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x46 = F
   0x0000,  // ************ ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3F80,  // **#######*** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x47 = G
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x33E0,  // **##**#####* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x48 = H
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x7FE0,  // *##########* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x49 = I
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4A = J
   0x0000,  // ************ ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4B = K
   0x0000,  // ************ ****
   0x30E0,  // **##****###* ****
   0x3180,  // **##***##*** ****
   0x3700,  // **##*###**** ****
   0x3C00,  // **####****** ****
   0x3700,  // **##*###**** ****
   0x3180,  // **##***##*** ****
   0x30E0,  // **##****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4C = L
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4D = M
   0x0000,  // ************ ****
   0x70E0,  // *###****###* ****
   0x79E0,  // *####**####* ****
   0x6F60,  // *##*####*##* ****
   0x6660,  // *##**##**##* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4E = N
   0x0000,  // ************ ****
   0x7060,  // *###*****##* ****
   0x7860,  // *####****##* ****
   0x6C60,  // *##*##***##* ****
   0x6660,  // *##**##**##* ****
   0x6360,  // *##***##*##* ****
   0x61E0,  // *##****####* ****
   0x60E0,  // *##*****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x4F = O
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0x50 = P
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FC0,  // **########** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x51 = Q
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3360,  // **##**##*##* ****
   0x1FC0,  // ***#######** ****
   0x0180,  // *******##*** ****
   0x00E0   // ********###* ****
  },
  { // 0x52 = R
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FC0,  // **########** ****
   0x3300,  // **##**##**** ****
   0x31C0,  // **##***###** ****
   0x30E0,  // **##****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x53 = S
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x54 = T
   0x0000,  // ************ ****
   0x7FE0,  // *##########* ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x55 = U
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x56 = V
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x1980,  // ***##**##*** ****
   0x0F00,  // ****####**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x57 = W
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x6F60,  // *##*####*##* ****
   0x39C0,  // **###**###** ****
   0x30C0,  // **##****##** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x58 = X
   0x0000,  // ************ ****
   0x30C0,  // **##****##** ****
   0x1980,  // ***##**##*** ****
   0x0F00,  // ****####**** ****
   0x0600,  // *****##***** ****
   0x0F00,  // ****####**** ****
   0x1980,  // ***##**##*** ****
   0x30C0,  // **##****##** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x59 = Y
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x30C0,  // **##****##** ****
   0x1980,  // ***##**##*** ****
   0x0F00,  // ****####**** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5A = Z
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0180,  // *******##*** ****
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0C00,  // ****##****** ****
   0x1800,  // ***##******* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5B = Ä = NC
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5C = Ö = NC
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5D = Ü = NC
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5E = ^ = NC
   0x0600,  // *****##***** ****
   0x0F00,  // ****####**** ****
   0x1980,  // ***##**##*** ****
   0x30C0,  // **##****##** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x5F = _ = NC
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x7FE0   // *##########* ****
  },

  { // 0x60 = ° = NC
   0x0000,  // ************ ****
   0x0000,  // *****####*** ****
   0x0000,  // ****##**##** ****
   0x0000,  // *****####*** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x61 = a
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x62 = b
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x37C0,  // **##*#####** ****
   0x3860,  // **###****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x63 = c
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0FE0,  // ****#######* ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
   0x1800,  // ***##******* ****
   0x0FE0,  // ****#######* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x64 = d
   0x0000,  // ************ ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x1F60,  // ***#####*##* ****
   0x30E0,  // **##****###* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FE0,  // ***########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x65 = e
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x66 = f
   0x0000,  // ************ ****
   0x07E0,  // *****######* ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x3F80,  // **#######*** ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x67 = g
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1F60,  // ***#####*##* ****
   0x30E0,  // **##****###* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0060,  // *********##* ****
   0x1FC0   // ***#######** ****
  },
  { // 0x68 = h
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x37C0,  // **##*#####** ****
   0x3860,  // **###****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x69 = i
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x6A = j
   0x0000,  // ************ ****
   0x00E0,  // ********###* ****
   0x0000,  // ************ ****
   0x01E0,  // *******####* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x0060,  // *********##* ****
   0x3060,  // **##*****##* ****
   0x1FC0   // ***#######** ****
  },
  { // 0x6B = k
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x30E0,  // **##****###* ****
   0x3180,  // **##***##*** ****
   0x3E00,  // **#####***** ****
   0x3180,  // **##***##*** ****
   0x30E0,  // **##****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x6C = l
   0x0000,  // ************ ****
   0x1E00,  // ***####***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x6D = m
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x6DC0,  // *##*##*###** ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x6E = n
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x37C0,  // **##*#####** ****
   0x3860,  // **###****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x6F = o
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0x70 = p
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x37C0,  // **##*#####** ****
   0x3860,  // **###****##* ****
   0x3060,  // **##*****##* ****
   0x3860,  // **###****##* ****
   0x37C0,  // **##*#####** ****
   0x3000,  // **##******** ****
   0x3000   // **##******** ****
  },
  { // 0x71 = q
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1EC0,  // ***####*##** ****
   0x31C0,  // **##***###** ****
   0x30C0,  // **##****##** ****
   0x31C0,  // **##***###** ****
   0x1EC0,  // ***####*##** ****
   0x00C0,  // ********##** ****
   0x01E0   // *******####* ****
  },
  { // 0x72 = r
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x33E0,  // **##**#####* ****
   0x3C00,  // **####****** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x73 = s
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0060,  // *********##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x74 = t
   0x0000,  // ************ ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x3F80,  // **#######*** ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x0C00,  // ****##****** ****
   0x07E0,  // *****######* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x75 = u
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x76 = v
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x30C0,  // **##****##** ****
   0x1980,  // ***##**##*** ****
   0x0F00,  // ****####**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x77 = w
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x36C0,  // **##*##*##** ****
   0x2980,  // ***##**##*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x78 = x
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x70E0,  // *###****###* ****
   0x1980,  // ***##**##*** ****
   0x0F00,  // ****####**** ****
   0x1980,  // ***##**##*** ****
   0x70E0,  // *###****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x79 = y
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x18C0,  // ***##***##** ****
   0x0D80,  // ****##*##*** ****
   0x0700,  // *****###**** ****
   0x0600,  // *****##***** ****
   0x0C00,  // ****##****** ****
   0x3800   // **###******* ****
  },
  { // 0x7A = z
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3FE0,  // **#########* ****
   0x0180,  // *******##*** ****
   0x0700,  // *****###**** ****
   0x0C00,  // ****##****** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x7B = ä = NC
   0x0000,  // ************ ****
   0x3180,  // **##***##*** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x7C = ö = NC
   0x0000,  // ************ ****
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x7D = ü = NC
   0x0000,  // ************ ****
   0x10C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x7E = ß = NC
   0x0000,  // ************ ****
   0x0F80,  // ****#####*** ****
   0x18C0,  // ***##***##** ****
   0x30C0,  // **##****##** ****
   0x3380,  // **##**###*** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x33C0,  // **##**####** ****
   0x3000,  // **##******** ****
   0x3000   // **##******** ****
  },
  { // 0x7F = Block
   0x0000,  // ************ ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x7FE0,  // *##########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0x80 = 
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x63E0,  // *##***#####* ****
   0x6660,  // *##**##**##* ****
   0x6660,  // *##**##**##* ****
   0x63E0,  // *##***#####* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000   // ************ ****
  },
  { // 0x81 = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x82 = 
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x7000,  // *###******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3180,  // **##***##*** ****
   0x0300,  // ******##**** ****
   0x0660,  // *****##**##* ****
   0x07E0,  // *****######* ****
   0x0060   // *********##* ****
  },
  { // 0x83 = 
   0x0000,  // ************ ****
   0x0FC0,  // ****######** ****
   0x1860,  // ***##****##* ****
   0x0C00,  // ****##****** ****
   0x3F00,  // **######**** ****
   0x0C00,  // ****##****** ****
   0x3E60,  // **#####**##* ****
   0x33C0,  // **##**####** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x84 = 
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x6660,  // *##**##**##* ****
   0x6600,  // *##**##***** ****
   0x3FC0,  // **########** ****
   0x0660,  // *****##**##* ****
   0x6660,  // *##**##**##* ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0000   // ************ ****
  },
  { // 0x85 = 
   0x07F0,  // *****####### ****
   0x0C00,  // ****##****** ****
   0x19F0,  // ***##**##### ****
   0x1800,  // ***##******* ****
   0x19F0,  // ***##**##### ****
   0x1800,  // ***##******* ****
   0x19F0,  // ***##**##### ****
   0x0C00,  // ****##****** ****
   0x07F0,  // *****####### ****
   0x0000   // ************ ****
  },
  { // 0x86 = 
   0xFFC0,  // ##########** ****
   0x1C60,  // ***###***##* ****
   0x0830,  // ****#*****## ****
   0x7F30,  // *#######**## ****
   0x4130,  // *#*****#**## ****
   0x7F30,  // *#######**## ****
   0x0830,  // ****#*****## ****
   0x1C60,  // ***###***##* ****
   0xFFC0,  // ##########** ****
   0x0000   // ************ ****
  },
  { // 0x87 = 
   0xFFC0,  // ##########** ****
   0x0060,  // *********##* ****
   0x3E30,  // **#####***## ****
   0x6330,  // *##***##**## ****
   0x0E30,  // ****###***## ****
   0x1830,  // ***##*****## ****
   0x1830,  // ***##*****## ****
   0x0060,  // *********##* ****
   0xFFC0,  // ##########** ****
   0x0000   // ************ ****
  },
  { // 0x88 = 
   0x0000,  // ************ ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x3980,  // ***##**##*** ****
   0x0000   // ************ ****
  },
  { // 0x89 = 
   0x0000,  // ************ ****
   0x7C00,  // *#####****** ****
   0x0C00,  // ****##****** ****
   0x3800,  // **###******* ****
   0x0C00,  // ****##****** ****
   0x7980,  // *####**##*** ****
   0x0300,  // ******##**** ****
   0x0660,  // *****##**##* ****
   0x07E0,  // *****######* ****
   0x0060   // *********##* ****
  },
  { // 0x8A = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x8B = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x1C00,  // ***###****** ****
   0x7FF0,  // *########### ****
   0x1C00,  // ***###****** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x8C = 
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x7000,  // *###******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x33C0,  // **##**####** ****
   0x0660,  // *****##**##* ****
   0x00C0,  // ********##** ****
   0x0300,  // ******##**** ****
   0x07E0   // *****######* ****
  },
  { // 0x8D = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0380,  // ******###*** ****
   0xFFE0,  // ###########* ****
   0x0380,  // ******###*** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x8E = 
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0F00,  // ****####**** ****
   0x1F80,  // ***######*** ****
   0x36C0,  // **##*##*##** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600   // *****##***** ****
  },
  { // 0x8F = 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x0000   // ************ ****
  },

  { // 0x90 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x3000,  // **##******** ****
   0x3F80,  // **#######*** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x91 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x92 = 
   0x0000,  // ************ ****
   0x3180,  // **##***##*** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x93 = 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x0000   // ************ ****
  },
  { // 0x94 = 
   0x0000,  // ************ ****
   0x6060,  // *##******##* ****
   0x30C0,  // **##****##** ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x6060,  // *##******##* ****
   0x0000   // ************ ****
  },
  { // 0x95 = 
   0xFFC0,  // ##########** ****
   0x0060,  // *********##* ****
   0xFF30,  // ########**## ****
   0x0030,  // **********## ****
   0xFF30,  // ########**## ****
   0x0030,  // **********## ****
   0xFF30,  // ########**## ****
   0x0060,  // *********##* ****
   0xFFC0,  // ##########** ****
   0x0000   // ************ ****
  },
  { // 0x96 = 
   0xFFC0,  // ##########** ****
   0x0060,  // *********##* ****
   0x3E30,  // **#####***## ****
   0x4730,  // *#***###**## ****
   0x4730,  // *#***###**## ****
   0x7F30,  // *#######**## ****
   0x3E30,  // **#####***## ****
   0x0060,  // *********##* ****
   0xFFC0,  // ##########** ****
   0x0000   // ************ ****
  },
  { // 0x97 = 
   0xFFC0,  // ##########** ****
   0x0860,  // ****#****##* ****
   0x1C30,  // ***###****## ****
   0x0030,  // **********## ****
   0x7F30,  // *#######**## ****
   0x0030,  // **********## ****
   0x1C30,  // ***###****## ****
   0x0860,  // ****#****##* ****
   0xFFC0,  // ##########** ****
   0x0000   // ************ ****
  },
  { // 0x98 = 
   0x0000,  // ************ ****
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x99 = 
   0x0E00,  // ****###***** ****
   0x1B00,  // ***##*##**** ****
   0x0E00,  // ****###***** ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9A = 
   0x0000,  // ************ ****
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9B = 
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9C = 
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9D = 
   0x0700,  // *****###**** ****
   0x0700,  // *****###**** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9E = 
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0x9F = _
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x7FE0   // *##########* ****
  },


  { // 0xA0 = 0x20a
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA1 = 0x21a 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA2 = 0x22a
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA3 = 0x23a 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA4 = 0x24a 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA5 = 0x25a 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA6 = 0x26a
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA7 = 0x27a
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA8 = 0x28a
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xA9 = 0x29a
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAA = 0x2Aa 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAB = 0x2Ba
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAC = 0x2Ca
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAD = 0x2Da
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAE = 0x2Ea 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xAF = 0x2Fa 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0xB0 = 0x30a
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB1 = 0x31a
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB2 = 0x32a 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB3 = 0x33a 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB4 = 0x34a 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB5 = 0x35a
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB6 = 0x36a 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB7 = 0x37a 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB8 = 0x38a 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xB9 = 0x39a 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBA = 0x3Aa 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBB = 0x3Ba 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBC = 0x3Ca 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBD = 0x3Da 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBE = 0x3Ea 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },
  { // 0xBF = 0x3Fa 
   0xFFFF,  // ############ ****
   0xFFFF,  // ############ ****
   0xFFFF,  // ############ ****
   0xFFFF,  // ############ ****
   0xFFFF,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00   // ######****** ****
  },

  { // 0xC0 = 
   0x0600,  // *****##***** ****
   0x0C00,  // ****##****** ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x6060,  // *##******##* ****
   0x7FE0,  // *##########* ****
   0x6000,  // *##********* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC1 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000   // ************ ****
  },
  { // 0xC2 = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC3 = 
   0x0000,  // ************ ****
   0x0FC0,  // ****######** ****
   0x1860,  // ***##****##* ****
   0x0C00,  // ****##****** ****
   0x3F00,  // **######**** ****
   0x0C00,  // ****##****** ****
   0x3E60,  // **#####**##* ****
   0x33C0,  // **##**####** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC4 = 
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x6660,  // *##**##**##* ****
   0x6600,  // *##**##***** ****
   0x3FC0,  // **########** ****
   0x0660,  // *****##**##* ****
   0x6660,  // *##**##**##* ****
   0x3F60,  // **########** ****
   0x06C0,  // *****##***** ****
   0x0000   // ************ ****
  },
  { // 0xC5 = 
   0x3CC0,  // **####**##** ****
   0x6780,  // *##**####*** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC6 = 
   0x3C60,  // **####***##* ****
   0x67C0,  // *##**#####** ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC7 = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC8 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xC9 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xCA = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xCB = 
   0x0000,  // ************ ****
   0x0780,  // *****####*** ****
   0x0CC0,  // ****##**##** ****
   0x0780,  // *****####*** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xCC = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0FE0,  // ****#######* ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
   0x1800,  // ***##******* ****
   0x0FE0,  // ****#######* ****
   0x0300,  // ******##**** ****
   0x0E00   // ****###***** ****
  },
  { // 0xCD = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0310,  // ******###*** ****
   0xFFE0,  // ###########* ****
   0x0310,  // ******###*** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xCE = 
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0F00,  // ****####**** ****
   0x1F80,  // ***######*** ****
   0x36C0,  // **##*##*##** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600   // *****##***** ****
  },
  { // 0xCF = 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x0000   // ************ ****
  },

  { // 0xD0 = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD1 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD2 = 
   0x0E00,  // ****###***** ****
   0x1B00,  // ***##*##**** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD3 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD4 = 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD5 = 
   0x1E60,  // ***####**##* ****
   0x33C0,  // **##**####** ****
   0x1F80,  // ***######*** ****
   0x30C0,  // **##****##** ****
   0x6060,  // *##******##* ****
   0x7FE0,  // *##########* ****
   0x6060,  // *##******##* ****
   0x6060,  // *##******##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD6 = 
   0x1E60,  // ***####**##* ****
   0x33C0,  // **##**####** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD7 = 
   0x0000,  // ************ ****
   0x0FC0,  // ****######** ****
   0x1860,  // ***##****##* ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x1860,  // ***##****##* ****
   0x0FC0,  // ****######** ****
   0x0300,  // ******##**** ****
   0x0E00   // ****###***** ****
  },
  { // 0xD8 = 
   0x0700,  // *****###**** ****
   0x0D80,  // ****##*##*** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xD9 = 
   0x0700,  // *****###**** ****
   0x0D80,  // ****##*##*** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xDA = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0FE0,  // ****#######* ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
   0x1800,  // ***##******* ****
   0x0FE0,  // ****#######* ****
   0x0300,  // ******##**** ****
   0x0E00   // ****###***** ****
  },
  { // 0xDB = 
   0x0000,  // ************ ****
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xDC = 
   0x0700,  // *****###**** ****
   0x0D80,  // ****##*##*** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xDD = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xDE = 
   0x0F00,  // ****####**** ****
   0x1980,  // ***##**##*** ****
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xDF = 
   0x0000,  // ************ ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x7FE0,  // *##########* ****
   0x1980,  // ***##**##*** ****
   0x1980,  // ***##**##*** ****
   0x0000   // ************ ****
  },

  { // 0xE0 = 
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE1 = 
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0600,  // *****##***** ****
   0x1800,  // ***##******* ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x1F00,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE2 = 
   0x0000,  // ************ ****
   0x18C0,  // ***##***##** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE3 = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0FE0,  // ****#######* ****
   0x1800,  // ***##******* ****
   0x3000,  // **##******** ****
   0x1800,  // ***##******* ****
   0x0FE0,  // ****#######* ****
   0x0300,  // ******##**** ****
   0x0E00   // ****###***** ****
  },
  { // 0xE4 = 
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x6660,  // *##**##**##* ****
   0x6600,  // *##**##***** ****
   0x3FC0,  // **########** ****
   0x0660,  // *****##**##* ****
   0x6660,  // *##**##**##* ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0000   // ************ ****
  },
  { // 0xE5 = 
   0x0000,  // ************ ****
   0x3F80,  // **#######*** ****
   0x6180,  // *##****##*** ****
   0x6180,  // *##****##*** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x7FE0,  // *##########* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE6 = 
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE7 = 
   0x1E60,  // ***####**##* ****
   0x33C0,  // **##**####** ****
   0x3860,  // **###****##* ****
   0x3C60,  // **####***##* ****
   0x3660,  // **##*##**##* ****
   0x3360,  // **##**##*##* ****
   0x31E0,  // **##***####* ****
   0x30E0,  // **##****###* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE8 = 
   0x1E60,  // ***####**##* ****
   0x33C0,  // **##**####** ****
   0x0000,  // ************ ****
   0x37C0,  // **##*#####** ****
   0x3860,  // **###****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xE9 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xEA = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xEB = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x7F80,  // *########*** ****
   0x00C0,  // ********##** ****
   0x3FC0,  // **########** ****
   0x60C0,  // *##*****##** ****
   0x3FE0,  // **#########* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xEC = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3000,  // **##******** ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xED = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x0E00,  // ****###***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xEE = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xEF = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x0000,  // ************ ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x30E0,  // **##****###* ****
   0x1F60,  // ***#####*##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0xF0 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF1 = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3FE0,  // **#########* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF2 = 
   0x0C00,  // ****##****** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x3000,  // **##******** ****
   0x3F00,  // **######**** ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF3 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF4 = 
   0x19C0,  // ***##**##*** ****
   0x0000,  // ************ ****
   0x3FC0,  // **########** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x0600,  // *****##***** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF5 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF6 = 
   0x0600,  // *****##***** ****
   0x0300,  // ******##**** ****
   0x1FC0,  // ***#######** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF7 = 
   0x0300,  // ******##**** ****
   0x0600,  // *****##***** ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x3060,  // **##*****##* ****
   0x1FC0,  // ***#######** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF8 = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x3DC0,  // **####*###** ****
   0x0660,  // *****##**##* ****
   0x3FE0,  // **#########* ****
   0x6600,  // *##**##***** ****
   0x3FC0,  // **########** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xF9 = 
   0x0000,  // ************ ****
   0x0FE0,  // ****#######* ****
   0x1B00,  // ***##*##**** ****
   0x3300,  // **##**##**** ****
   0x7FC0,  // *#########** ****
   0x6300,  // *##***##**** ****
   0x6300,  // *##***##**** ****
   0x63E0,  // *##***#####* ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xFA = 
   0x0000,  // ************ ****
   0x0300,  // ******##**** ****
   0x0FC0,  // ****######** ****
   0x0180,  // *******##*** ****
   0x1FC0,  // ***#######** ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x1F80,  // ***######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xFB = 
   0x0000,  // ************ ****
   0x3F80,  // **#######*** ****
   0x30C0,  // **##****##** ****
   0x3060,  // **##*****##* ****
   0x7C60,  // *#####***##* ****
   0x3060,  // **##*****##* ****
   0x30C0,  // **##****##** ****
   0x3F80,  // **#######*** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },
  { // 0xFC = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0180,  // *******##*** ****
   0x3FC0,  // **########** ****
   0x6360,  // *##***##*##* ****
   0x6660,  // *##**##**##* ****
   0x6C60,  // *##*##***##* ****
   0x3FC0,  // **########** ****
   0x1800,  // ***##******* ****
   0x0000   // ************ ****
  },
  { // 0xFD = 
   0x0060,  // *********##* ****
   0x3FC0,  // **########** ****
   0x61E0,  // *##****####* ****
   0x6360,  // *##***##*##* ****
   0x6660,  // *##**##**##* ****
   0x6C60,  // *##*##***##* ****
   0x7860,  // *####****##* ****
   0x3FC0,  // **########** ****
   0x6000,  // *##********* ****
   0x0000   // ************ ****
  },
  { // 0xFE = 
   0x0000,  // ************ ****
   0x3000,  // **##******** ****
   0x3000,  // **##******** ****
   0x3F80,  // **#######*** ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x30C0,  // **##****##** ****
   0x3F80,  // **#######*** ****
   0x3000,  // **##******** ****
   0x3000   // **##******** ****
  },
  { // 0xFF = 
   0x3C00,  // **####****** ****
   0x1800,  // ***##******* ****
   0x1F80,  // ***######*** ****
   0x18C0,  // ***##***##** ****
   0x18C0,  // ***##***##** ****
   0x1F80,  // ***######*** ****
   0x1800,  // ***##******* ****
   0x3C00,  // **####****** ****
   0x0000,  // ************ ****
   0x0000   // ************ ****
  },

  { // 0x60a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x61a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x62a = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x63a = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x64a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x65a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x66a = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x67a = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x68a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x69a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Aa = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Ba = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Ca = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Da = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Ea = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },
  { // 0x6Fa = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0   // ******###### ****
  },

  { // 0x70a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x71a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x72a = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x73a = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x74a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x75a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x76a = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x77a = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x78a = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x79a = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Aa = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Ba = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Ca = 
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0x0000,  // ************ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Da = 
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFC00,  // ######****** ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Ea = 
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0x03F0,  // ******###### ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0   // ############ ****
  },
  { // 0x7Fa = 
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
   0xFFF0,  // ############ ****
  }
};
   


int NationalOptionSubsetG0Default[13]=
    {0x23,0x94,0x80,0   ,0   ,0   ,0x5e,0x5f,0   ,0   ,0   ,0   ,0   };

int NationalOptionSubsetCZ_SK[13]=
    {0x23,0   ,0   ,0   ,0   ,0   ,0xed,0   ,0xec,0xeb,0   ,0xef,0   };
int NationalOptionSubsetEN[13]=
    {0x83,0x24,0x80,0x8b,0x8c,0x8d,0x8e,0x23,0x81,0x82,0x88,0x89,0x8a};
int NationalOptionSubsetEE[13]=
    {0x23,0xc6,0   ,0x5b,0x5c,0   ,0x5d,0xd6,0   ,0x7b,0x7c,0   ,0x7d};
int NationalOptionSubsetFR[13]=
    {0xd3,0xd4,0xd0,0xdb,0xdc,0xc1,0xde,0x23,0xd1,0xd2,0xd8,0xd9,0xcc};
int NationalOptionSubsetDE[13]=
    {0x23,0x24,0x40,0x5b,0x5c,0x5d,0x5e,0x5f,0x60,0x7b,0x7c,0x7d,0x7e};
int NationalOptionSubsetIT[13]=
    {0x83,0x24,0xd3,0x60,0xcc,0x8d,0x8e,0x23,0xdd,0xc1,0xc8,0xc9,0xca};
int NationalOptionSubsetLV_LT[13]=
    {0x23,0x24,0   ,0   ,0   ,0   ,0   ,0   ,0   ,0   ,0   ,0   ,0   };
int NationalOptionSubsetPL[13]=
    {0x23,0   ,0   ,0   ,0   ,0   ,0   ,0xee,0   ,0   ,0   ,0   ,0   };
int NationalOptionSubsetPT_ES[13]=
    {0xcc,0x24,0xe0,0xeb,0xec,0xed,0xee,0xef,0xe1,0x7d,0xe8,0xc9,0xc2};
int NationalOptionSubsetRO[13]=
    {0x23,0x94,0   ,0   ,0   ,0   ,0   ,0   ,0   ,0xd2,0   ,0   ,0xde};
int NationalOptionSubsetSR_HR_SL[13]=
    {0x23,0   ,0   ,0   ,0   ,0xfb,0   ,0xdb,0   ,0   ,0   ,0   ,0   };
int NationalOptionSubsetSV_FI[13]=
    {0x23,0x94,0x90,0x5b,0x5c,0x9d,0x5d,0x5f,0x91,0x7b,0x7c,0x99,0x7d};
int NationalOptionSubsetTR[13]=
    {0   ,0   ,0   ,0   ,0x5c,0xd7,0x5d,0   ,0   ,0   ,0x7c,0xcc,0x7d};



inline int NationalOptionSubset(int chr) {
    switch (chr) {
        case 0x23: return 0;
        case 0x24: return 1;
        case 0x40: return 2;
        case 0x5b: return 3;
        case 0x5c: return 4;
        case 0x5d: return 5;
        case 0x5e: return 6;
        case 0x5f: return 7;
        case 0x60: return 8;
        case 0x7b: return 9;
        case 0x7c: return 10;
        case 0x7d: return 11;
        case 0x7e: return 12;
    }
    return -1;      
}   

inline unsigned int LeftBits(unsigned int bits) {
    // Scale bit positions 0xfc00 to 0xfff0 positions
    unsigned int res=0;
    if (bits&0x8000) res|=0xC000;
    if (bits&0x4000) res|=0x3000;
    if (bits&0x2000) res|=0x0C00;
    if (bits&0x1000) res|=0x0300;
    if (bits&0x0800) res|=0x00C0;
    if (bits&0x0400) res|=0x0030;
    return res;
}
inline unsigned int RightBits(unsigned int bits) {
    // Scale bit positions 0x03f0 to 0xfff0 positions
    unsigned int res=0;
    if (bits&0x0200) res|=0xC000;
    if (bits&0x0100) res|=0x3000;
    if (bits&0x0080) res|=0x0C00;
    if (bits&0x0040) res|=0x0300;
    if (bits&0x0020) res|=0x00C0;
    if (bits&0x0010) res|=0x0030;
    return res;
}



unsigned int* GetFontChar(cTeletextChar c, unsigned int *buffer) {
    // Get character bitmap for character/charset

    enumCharsets font=c.GetCharset();
    int chr=c.GetChar();
    unsigned int *bitmap=NULL;
    int i;
    int NationalOption=NationalOptionSubset(chr);
    
    switch (font) {
    case CHARSET_LATIN_G0:
        if (NationalOption>=0) {
            if (NationalOptionSubsetG0Default[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetG0Default[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }
        break;
    case CHARSET_LATIN_G0_EN:
        if (NationalOption>=0) {
            if (NationalOptionSubsetEN[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetEN[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }           
        break;
    case CHARSET_LATIN_G0_FR:
        if (NationalOption>=0) {
            if (NationalOptionSubsetFR[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetFR[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }           
        break;
    case CHARSET_LATIN_G0_IT:
        if (NationalOption>=0) {
            if (NationalOptionSubsetIT[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetIT[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }           
        break;
    case CHARSET_LATIN_G0_PT_ES:
        if (NationalOption>=0) {
            if (NationalOptionSubsetPT_ES[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetPT_ES[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }           
        break;
    case CHARSET_LATIN_G0_SV_FI:
        if (NationalOption>=0) {
            if (NationalOptionSubsetSV_FI[NationalOption]>0)
                bitmap=TXT_Font[NationalOptionSubsetSV_FI[NationalOption]-0x20];
        } else {
            if (chr>=0x20 && chr<0x80) {
                bitmap=TXT_Font[chr-0x20];
            }
        }           
        break;
    case CHARSET_LATIN_G0_DE:
        if (chr>=0x20 && chr<0x80) {
            bitmap=TXT_Font[chr-0x20];
        }
        break;
    case CHARSET_LATIN_G0_CZ_SK:
    case CHARSET_LATIN_G0_EE:
    case CHARSET_LATIN_G0_LV_LT:
    case CHARSET_LATIN_G0_PL:
    case CHARSET_LATIN_G0_RO:
    case CHARSET_LATIN_G0_SR_HR_SL:
    case CHARSET_LATIN_G0_TR:
        // Partially supported latin charsets
        if (chr>=0x20 && chr<0x80 && NationalOption<0) {
            bitmap=TXT_Font[chr-0x20];
        }
        break;
        
    case CHARSET_LATIN_G2:
    case CHARSET_CYRILLIC_G0_SR_HR:
    case CHARSET_CYRILLIC_G0_RU_BG:
    case CHARSET_CYRILLIC_G0_UK:
    case CHARSET_CYRILLIC_G2:
    case CHARSET_GREEK_G0:
    case CHARSET_GREEK_G2:
    case CHARSET_ARABIC_G0:
    case CHARSET_ARABIC_G2:
    case CHARSET_HEBREW_G0:
        // totally unsupported
        break;
        
    case CHARSET_GRAPHICS_G1:
        if (chr>=0x20 && chr<0x40) {
            bitmap=TXT_Font[chr-0x20+0x80];
        } else if (chr>=0x60 && chr<0x80) {
            bitmap=TXT_Font[chr-0x60+0xE0];
        }
        break;
    case CHARSET_GRAPHICS_G1_SEP:
        if (chr>=0x20 && chr<0x40) {
            bitmap=TXT_Font[chr-0x20+0x80];
        } else if (chr>=0x60 && chr<0x80) {
            bitmap=TXT_Font[chr-0x60+0xE0];
        }
        if (bitmap) {
            for (i=0;i<10;i++) buffer[i]=bitmap[i]&TXT_Mask[i];
            bitmap=buffer;
        }
        break;
        
    case CHARSET_GRAPHICS_G3:
    case CHARSET_INVALID:
        // Totally unsupported
        break;
    }
    
    
    
    if (!buffer) {
        printf("Warning: Undefined char: %x %x\n",font,chr);
        return NULL;
    }
    
    switch (c.GetDblHeight()) {
    case dblh_Top:
        // Scale top 5 lines to full height
        buffer[8]=buffer[9]=bitmap[4];
        buffer[6]=buffer[7]=bitmap[3];
        buffer[4]=buffer[5]=bitmap[2];
        buffer[2]=buffer[3]=bitmap[1];
        buffer[1]=buffer[0]=bitmap[0];
        bitmap=buffer;
        break;
    case dblh_Bottom:
        // Scale bottom 5 lines to full height
        buffer[0]=buffer[1]=bitmap[5];
        buffer[2]=buffer[3]=bitmap[6];
        buffer[4]=buffer[5]=bitmap[7];
        buffer[6]=buffer[7]=bitmap[8];
        buffer[8]=buffer[9]=bitmap[9];
        bitmap=buffer;
    default:;
    }

    switch (c.GetDblWidth()) {
    case dblw_Left:
        // Scale 6 left columns to full width
        buffer[0]=LeftBits(bitmap[0]);
        buffer[1]=LeftBits(bitmap[1]);
        buffer[2]=LeftBits(bitmap[2]);
        buffer[3]=LeftBits(bitmap[3]);
        buffer[4]=LeftBits(bitmap[4]);
        buffer[5]=LeftBits(bitmap[5]);
        buffer[6]=LeftBits(bitmap[6]);
        buffer[7]=LeftBits(bitmap[7]);
        buffer[8]=LeftBits(bitmap[8]);
        buffer[9]=LeftBits(bitmap[9]);
        bitmap=buffer;
        break;
    case dblw_Right:
        // Scale 6 right columns to full width
        buffer[0]=RightBits(bitmap[0]);
        buffer[1]=RightBits(bitmap[1]);
        buffer[2]=RightBits(bitmap[2]);
        buffer[3]=RightBits(bitmap[3]);
        buffer[4]=RightBits(bitmap[4]);
        buffer[5]=RightBits(bitmap[5]);
        buffer[6]=RightBits(bitmap[6]);
        buffer[7]=RightBits(bitmap[7]);
        buffer[8]=RightBits(bitmap[8]);
        buffer[9]=RightBits(bitmap[9]);
        bitmap=buffer;
    default:;
    }
    
    return bitmap;      
}
